| Title: | Tools for the IUCN Red List of Ecosystems and Species |
| Version: | 2.1.0 |
| Description: | A toolbox created by members of the International Union for Conservation of Nature (IUCN) Red List of Ecosystems Committee for Scientific Standards. Primarily, it is a set of tools suitable for calculating the metrics required for making assessments of species and ecosystems against the IUCN Red List of Threatened Species and the IUCN Red List of Ecosystems categories and criteria. See the IUCN website for detailed guidelines, the criteria, publications and other information. |
| License: | GPL (≥ 3) | file LICENSE |
| URL: | https://github.com/red-list-ecosystem/redlistr, http://red-list-ecosystem.github.io/redlistr/ |
| BugReports: | https://github.com/red-list-ecosystem/redlistr/issues |
| Depends: | R (≥ 4.1.0) |
| Imports: | terra (≥ 1.8-54), sf (≥ 1.0-21), dplyr, methods, ggplot2, rlang, units, stringr, mgcv |
| Suggests: | devtools, knitr, rmarkdown, testthat, leaflet |
| VignetteBuilder: | knitr |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Config/Needs/website: | rmarkdown |
| LazyData: | true |
| NeedsCompilation: | no |
| Packaged: | 2026-07-09 23:38:24 UTC; z3531221 |
| Author: | Calvin Lee |
| Maintainer: | Aniko Toth <anikobtoth@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-07-14 07:30:02 UTC |
AOOgrid class
Description
A class to represent an AOO grid object
Slots
namethe name of the assessment unit
gridan AOO grid as a shapefile
AOOthe number of grid squares in grid
paramsa named vector of input parameters (grid size, jitter, n_jitter)
pctrulelogical indicating whether the 1% rule was applied
inputthe input ecosystem data used to generate the AOO grid
AOOvalsthe list of AOO values
EOO class
Description
A class to represent an EOO convex hull object
Slots
namethe name of the assessment unit
polan EOO convex hull polygon
EOOthe area of the EOO polygon as a numeric
unitthe unit in which the area is provided
inputthe input ecosystem data used to generate the EOO polygon
Mangrove area combined
Description
Area of mangroves in 2000 and 2017
Usage
a
Format
a
A data frame with 2 rows and 3 columns:
- layer
name of the layer
- value
raster value from which area was computed
- area
area in km2
computed from mangrove.2000 and mangrove.2017 using getArea
Mangrove distribution data
Description
Mangrove distribution from the northern regions of Western Port Bay, Victoria, Australia, in the year 2000.
Usage
a.2000
Format
a.2000
A data frame with 1 row and 3 columns:
- layer
name of the layer
- value
raster value from which area was computed
- area
area in km2
Details
The dataset is stored as a GeoTIFF file in inst/extdata and can be loaded with:
terra::rast(system.file("extdata", "example_distribution_2000.tif", package = "redlistr"))
The dataset is stored as a GeoTIFF file in inst/extdata and can be loaded with:
terra::rast(system.file("extdata", "example_distribution_2017.tif", package = "redlistr"))
Mangrove area
Area of mangroves in 2000
https://onlinelibrary.wiley.com/doi/10.1111/j.1466-8238.2010.00584.x/abstract Mangrove distribution data
Mangrove distribution from the northern regions of Western Port Bay, Victoria, Australia, in the year 2017.
computed from mangrove.2000 using getArea
Mangrove area
Description
Area of mangroves in 2017
Usage
a.2017
Format
a.2017
A data frame with 1 row and 3 columns:
- layer
name of the layer
- value
raster value from which area was computed
- area
area in km2
computed from mangrove.2017 using getArea
AOOgrid as.list
Description
as.list method for AOOgrid object
Usage
## S3 method for class 'AOOgrid'
as.list(x, ...)
Arguments
x |
an AOOgrid object |
... |
additional arguments |
EOO as.list
Description
as.list method for EOO object
Usage
## S3 method for class 'EOO'
as.list(x, ...)
Arguments
x |
an EOO object |
... |
additional arguments |
Compute AOO and EOO, return as table
Description
bundle performs AOO and EOO calculations on an input object and returns the results as a table
Usage
bundle(input_data, names_from = NA, ...)
Arguments
input_data |
Spatial object of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
names_from |
name of the column containing ecosystem names. If missing all features will be analysed together. Only needed for vector data. |
... |
Additional graphical parameters passed to getAOO(). |
Value
a data.frame containing AOO and EOO information for all input units as rows.
Author(s)
Aniko B. Toth anikobtoth@gmail.com
See Also
Other synthesis functions:
list2table()
Create empty Area of Occupancy (AOO) Grid.
Description
createGrid produces empty grid which can be used as the basis to help
compute AOO.
Usage
createGrid(input_data, cell_size = 10000)
Arguments
input_data |
Spatial object (sf or SpatRaster) of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
cell_size |
A number specifying the width of the desired grid square (in same units as your coordinate reference system) |
Value
A regular grid raster with extent input_data expanded by two
cells in each direction and grid size cell_size. Each grid square has a
unique raster value that serves as its identification number.
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com, Aniko B. Toth anikobtoth@gmail.com
References
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
See Also
Other AOO functions:
getAOO(),
jplot(),
makeAOOGrid(),
top_pct()
Decline forecasts
Description
declineForecast calculates rates of change from two inputs and extrapolates the
rate of change to a desired future time interval.
Usage
declineForecast(
x,
y,
names_from_x = NA,
names_from_y = NA,
t1,
year_diff,
forecast_year = t1 + 50
)
Arguments
x |
SpatRaster, SpatVector, or sf object representing one or more ecosystems or a data frame with two columns, one of them labeled "area", and the other containing ecosystem labels names_from_x. |
y |
SpatRaster, SpatVector, or sf object representing one or more ecosystems or a data frame with two columns, one of them labeled "area", and the other containing ecosystem labels names_from_y. |
names_from_x |
name of column containing ecosystem labels. Ignored if x is a raster. |
names_from_y |
name of column containing ecosystem labels. Ignored if y is a raster. names_from_x used if not provided. |
t1 |
numeric year of earliest dataset, corresponding to x |
year_diff |
numeric year difference between x and y inputs |
forecast_year |
the desired year to which to forecast (or hindcast) change. |
Value
returns a list of two elements: a table of areas and change in areas and a table of forecasts including decline rate, forecast area, and forecast percent decline.
Author(s)
Aniko B. Toth anikobtoth@gmail.com
See Also
Other Change functions:
getArea(),
getAreaChange(),
getAreaTrend(),
getDeclineStats()
Extrapolate Estimate
Description
extrapolateEstimate uses rates of decline from getDeclineStats
to extrapolate estimates to a given time
Usage
extrapolateEstimate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)
Arguments
A.t1 |
Area at time t1 |
year.t1 |
Year of time t1 |
nYears |
Number of years since t1 for prediction. Use negative values for backcasting |
ARD |
Absolute rate of decline |
PRD |
Proportional rate of decline |
ARC |
Annual rate of change |
Value
A dataframe with the forecast year, and a combination of:
Values as extrapolated with absolute rate of decline (ARD)
Values as extrapolated with proportional rate of decline (PRD)
Values as extrapolated with annual rate of change (ARC)
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com
References
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp.
See Also
Other change_functions:
futureAreaEstimate(),
sequentialExtrapolate()
Examples
a.r1 <- 23.55
a.r2 <- 15.79
decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012,
methods = 'PRD')
a.2040.PRD <- extrapolateEstimate(a.r1, a.r2, year.t1 = 1990, nYears = 50,
PRD = decline.stats$PRD)
Future Area Estimate
Description
futureAreaEstimate is now deprecated, please use
extrapolateEstimate instead
Usage
futureAreaEstimate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)
Arguments
A.t1 |
Area at time t1 |
year.t1 |
Year of time t1 |
nYears |
Number of years since t1 for area prediction |
ARD |
Absolute rate of decline |
PRD |
Proportional rate of decline |
ARC |
Annual rate of change |
Value
A dataframe with the forecast year, and a combination of:
Future area as estimated with absolute rate of decline (ARD)
Future area as estimated with proportional rate of decline (PRD)
Future area as estimated with annual rate of change (ARC)
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com
References
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp.
See Also
Other change_functions:
extrapolateEstimate(),
sequentialExtrapolate()
Compute Area of Occupancy (AOO)
Description
getAOO determines the number of area of occupancy (AOO) grid cells
occupied by a species or ecosystem. It includes capability for specifying
whether at least one percent of the grid cell needs to be occupied before it
is counted in the AOO. This functionality is important for assessing the IUCN
Red List of Ecosystems Criteria B.
Usage
getAOO(
input_data,
cell_size = 10000,
names_from = NA,
bottom_1pct_rule = TRUE,
percent = 1,
jitter = 150,
n_jitter = 35
)
Arguments
input_data |
Spatial object (sf or SpatRaster) of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
cell_size |
A number specifying the width of the desired grid square (in same units as your coordinate reference system) |
names_from |
the name of the column containing ecosystem labels |
bottom_1pct_rule |
Logical. If |
percent |
Numeric. The minimum percent to be applied as a threshold for
the |
jitter |
Integer. 0 = do not jitter, 1 = force jitter, another number indicates conditional jitter, the number of AOO cells under which to jitter, and over which not to jitter the grid. |
n_jitter |
the number of grids to test for ecosystems near the AOO thresholds. Ignored if jitter = FALSE. |
Value
an object of class AOOgrid or a list of AOOgrid objects. Ecosystems that received an AOO of 60 cells or fewer on a first pass are run with a jittered grid with n specified by n_jitter
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com, Aniko B. Toth anikobtoth@gmail.com
References
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
See Also
Other AOO functions:
createGrid(),
jplot(),
makeAOOGrid(),
top_pct()
Calculates the Area of ecosystems in spatial data
Description
getArea reports the area of ecosystem units provided as spatial data
Usage
getArea(x, names_from = NA, ...)
Arguments
x |
A SpatRaster, SpatVector, or an sf object with POLYGONS geometry. |
names_from |
a column names containing ecosystem labels, as a string or dplyr-style column name. Only required for SpatVector and sf types. Units are assumed to be delineated by raster value for SpatRasters. |
... |
Addition arguments based on input format |
Value
A data frame containing ecosystem identifiers and the total area of the ecosystem units in x as a units vector (km^2). For raster bricks it also contains the layer number.
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com, Aniko B. Toth anikobtoth@gmail.com
See Also
Other Change functions:
declineForecast(),
getAreaChange(),
getAreaTrend(),
getDeclineStats()
Area change between two inputs in km2
Description
getAreaChange reports the difference in area between two inputs. Inputs
can be SpatRaster, SpatVector, sf or a data frame of areas and may contain
data for multiple ecosystem types. Ensure x and y are the same data type.
If using data frame as input, ensure areas are measured in km2
Usage
getAreaChange(x, y, names_from_x = NA, names_from_y = NA)
Arguments
x |
SpatRaster, SpatVector, or sf object representing one or more ecosystems or a data frame with two columns, one of them labeled "area", and the other containing ecosystem labels names_from_x. |
y |
SpatRaster, SpatVector, or sf object representing one or more ecosystems or a data frame with two columns, one of them labeled "area", and the other containing ecosystem labels names_from_y. |
names_from_x |
name of column containing ecosystem labels. Ignored if x is a raster. |
names_from_y |
name of column containing ecosystem labels. Ignored if y is a raster. names_from_x used if not provided. |
Value
Returns a table containing ecosystem labels, areas, and the difference in area of the two inputs in km2
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com, Aniko B. Toth anikobtoth@gmail.com
See Also
Other Change functions:
declineForecast(),
getArea(),
getAreaTrend(),
getDeclineStats()
Examples
if (requireNamespace("terra", quietly = TRUE)) {
ok <- try({
m1 <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), 25, 20)
r1 <- terra::rast(m1)
terra::crs(r1) <- "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs"
m2 <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), 25, 20)
r2 <- terra::rast(m2)
terra::crs(r2) <- "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs"
getAreaChange(r1, r2)
}, silent = TRUE)
}
Extracts the area from an EOO polygon
Description
getEOOarea wrapper that extracts the area slot of the EOO input
Usage
getAreaEOO(EOO)
Arguments
EOO |
an object of class EOO |
Value
an integer
See Also
Other EOO functions:
getEOO(),
makeEOO()
Calculate area trends of ecosystems
Description
getAreaTrend is used to calculate changes in area over time. Output
is a list can be used to easily visualise trends for one ecosystem at a time.
Usage
getAreaTrend(x, names_from = NA)
Arguments
x |
SpatRaster with multiple layers or data frame containing two numerical columns "area" and "time". The data.frame can contain an additional column containing a key, whose name should be placed in names_from. |
names_from |
name of column containing ecosystem labels. Ignored if x is a raster. |
Value
returns a list
Author(s)
Aniko B. Toth anikobtoth@gmail.com
See Also
Other Change functions:
declineForecast(),
getArea(),
getAreaChange(),
getDeclineStats()
Change statistics.
Description
getDeclineStats calculates the Proportional Rate of Decline (PRD),
Absolute Rate of Decline (ARD) and Annual Rate of Change (ARC), given two
areas at two points in time. Also provides the total area difference. Inputs
are usually the results from getArea.
Usage
getDeclineStats(A.t1, A.t2, year.t1, year.t2, methods)
Arguments
A.t1 |
Area at time t1 |
A.t2 |
Area at time t2 |
year.t1 |
Year of time t1 |
year.t2 |
Year of time t2 |
methods |
Method(s) used to calculate rate of decline. Either 'PRD', 'ARD', and/or 'ARC'. See vignette to see a more detailed explanation for each of them. |
Value
A dataframe with absolute differences between the two inputs, and a selection of:
Proportional Rate of Decline (PRD)
Absolute Rate of Decline (ARD)
Annual Rate of Change (ARC)
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com
References
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp. Puyravaud, J.-P. 2003. Standardizing the calculation of the annual rate of deforestation. Forest Ecology and Management, 177, 593-596.
See Also
Other Change functions:
declineForecast(),
getArea(),
getAreaChange(),
getAreaTrend()
Examples
a.r1 <- 23.55
a.r2 <- 15.79
decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012,
methods = c('ARD', 'ARC'))
Calculates area of the created EOO polygon and returns a summary object with useful info.
Description
getEOO calculates the area of the EOO polygon generated from
makeEOO the provided data and returns an EOO class object or a list of these with
defined summary and plot functions available.
Usage
getEOO(input_data, names_from = NA)
Arguments
input_data |
Spatial object of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
names_from |
name of the column containing ecosystem names. If missing all features will be analysed together. Only needed for vector data. |
Value
An object of type EOO or a list of EOO objects that store the EOO polygon, its area, and its input_data
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com
See Also
Other EOO functions:
getAreaEOO(),
makeEOO()
Examples
if (requireNamespace("terra", quietly = TRUE)) {
ok <- try({
m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20)
r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs")
EOO <- getEOO(r1)
}, silent = TRUE)
}
AOOgrid hist
Description
hist method for AOOgrid objects
Usage
## S4 method for signature 'AOOgrid'
hist(x, ...)
Arguments
x |
an AOOgrid object |
... |
Additional graphical parameters passed to |
Union of spatial classes
Description
Allows either sf, spatVector, or SpatRaster objects in the spatial slot.
Make elbow plot to check jitter iterations
Description
jplot creates an elbow plot of the min AOO against
the number of grid replicates run. Jplots that fall to the
minimum value well before the highest n are robust.
Usage
jplot(x)
Arguments
x |
an AOOgrid object |
Value
NULL; plots min AOO against number of reps
Author(s)
Aniko B. Toth anikobtoth@gmail.com
See Also
Other AOO functions:
createGrid(),
getAOO(),
makeAOOGrid(),
top_pct()
Summarises a list of EOO or AOOgrid objects in a table
Description
list2table wrapper that summarises a list of EOO or AOOgrid objects as a table.
Usage
list2table(l)
Arguments
l |
a list of EOO or AOOgrid objects |
Value
a data.frame
See Also
Other synthesis functions:
bundle()
Create Area of Occupancy (AOO) grid for an ecosystem or species distribution
Description
makeAOOGrid is a generic function that creates grids representing the
area of occupancy for distributions based on the input spatial data. It
includes capability for specifying whether the least occupied cells collectively
containing less than 1% of the ecosystem are counted in the AOO. This functionality is
important for assessing the IUCN Red List of Ecosystems Criteria B.
Usage
makeAOOGrid(
input_data,
cell_size = 10000,
names_from = NA,
bottom_1pct_rule = TRUE,
percent = 1,
jitter = 150,
n_jitter = 35
)
Arguments
input_data |
Spatial object (sf or SpatRaster) of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
cell_size |
A number specifying the width of the desired grid square (in same units as your coordinate reference system) |
names_from |
the name of the column containing ecosystem labels |
bottom_1pct_rule |
Logical. If |
percent |
Numeric. The minimum percent to be applied as a threshold for
the |
jitter |
Integer. 0 = do not jitter, 1 = force jitter, another number indicates conditional jitter, the number of AOO cells under which to jitter, and over which not to jitter the grid. |
n_jitter |
the number of grids to test for ecosystems near the AOO thresholds. Ignored if jitter = FALSE. |
Value
A shapefile of grid cells occupied by an ecosystem or species, or a list of these if multiple ecosystems were input.
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com, Aniko B. Toth anikobtoth@gmail.com
References
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
See Also
Other AOO functions:
createGrid(),
getAOO(),
jplot(),
top_pct()
Examples
if (requireNamespace("terra", quietly = TRUE)) {
ok <- try({
m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20)
r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs")
AOO_grid <- makeAOOGrid(r1, cell_size = 3)
}, silent = TRUE)
}
Creates Extent of occurrence (EOO) Polygon
Description
makeEOO is a generic function that creates a minimum convex polygon
enclosing all occurrences of the ecosystems provided in the input data. If the input provided
is a raster layer, the points are taken from a buffer that has the radius of
half of the shorter edge of the pixel around the centroid.
Usage
makeEOO(input_data, names_from)
Arguments
input_data |
Spatial object of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
names_from |
name of the column containing ecosystem names. If missing all features will be analysed together. Only needed for vector data. |
Value
An object of class sf representing the EOO of
input_data, or a list of sf objects if multiple ecosystems were input.
Also inherits its CRS from input_data.
Author(s)
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com
References
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp.
See Also
Other EOO functions:
getAreaEOO(),
getEOO()
Examples
if (requireNamespace("terra", quietly = TRUE)) {
ok <- try({
m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20)
r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs")
EOO.polygon <- makeEOO(r1)
}, silent = TRUE)
}
AOOgrid plot
Description
plot method for AOOgrid object
Usage
## S4 method for signature 'AOOgrid,ANY'
plot(x, title = x@name)
Arguments
x |
an AOOgrid object |
title |
plot title, defaults to the assessment unit name. |
EOO plot
Description
plot method for EOO object
Usage
## S4 method for signature 'EOO,ANY'
plot(x, title = x@name)
Arguments
x |
an EOO object |
title |
Plot title, defaults to name of assessment unit. |
trend plot
Description
plot method for trend object
Usage
## S4 method for signature 'trend,ANY'
plot(x, y, ...)
Arguments
x |
an trend object |
y |
Ignored. Included for consistency with the |
... |
Additional graphical parameters passed to |
Safely project SpatRaster object CRS
Description
Safely project SpatRaster object CRS
Usage
safe_project(x, crs)
Safely transform sf object CRS
Description
Safely transform sf object CRS
Usage
safe_transform(x, crs)
Sequential extrapolation estimate
Description
sequentialExtrapolate uses rates of decline from getDeclineStats and
generates a sequence of estimates at regular time-steps. Useful for
generating a sequence for plotting graphs.
Usage
sequentialExtrapolate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)
Arguments
A.t1 |
Area at time t1 |
year.t1 |
Year of time t1 |
nYears |
Number of years since t1 for prediction. Use negative values for backcasting |
ARD |
Absolute rate of decline |
PRD |
Proportional rate of decline |
ARC |
Annual rate of change |
Value
A dataframe with the forecast year, and a combination of:
Sequence of values as extrapolated with absolute rate of decline (ARD)
Sequence of values as extrapolated with proportional rate of decline (PRD)
Sequence of values as extrapolated with annual rate of change (ARC)
Author(s)
Calvin Lee calvinkflee@gmail.com
References
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp.
See Also
Other change_functions:
extrapolateEstimate(),
futureAreaEstimate()
Examples
a.r1 <- 23.55
a.r2 <- 15.79
decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012,
methods = 'PRD')
a.2040.PRD.seq <- sequentialExtrapolate(a.r1, a.r2, year.t1 = 1990, nYears = 50,
PRD = decline.stats$PRD)
AOOgrid show
Description
show method for AOOgrid object
Usage
## S4 method for signature 'AOOgrid'
show(object)
Arguments
object |
an AOOgrid object |
EOO show
Description
show method for EOO object
Usage
## S4 method for signature 'EOO'
show(object)
Arguments
object |
an EOO object |
AOOgrid summary
Description
summary method for AOOgrid object
Usage
## S4 method for signature 'AOOgrid'
summary(object)
Arguments
object |
an AOOgrid object |
EOO summary
Description
summary method for EOO object
Usage
## S4 method for signature 'EOO'
summary(object)
Arguments
object |
an EOO object |
trend summary
Description
summary method for trend object
Usage
## S4 method for signature 'trend'
summary(object)
Arguments
object |
a trend object |
Identify positions of the bottom 1% of ecosystem area in AOO grid
Description
top_pct returns the vector positions of the largest elements
collectively comprising a given percentage more of the vector sum. This function
helps perform the bottom_1pct_rule when selecting the AOO grid by
identifying grid positions to keep.
Usage
top_pct(v, pct = 99)
Arguments
v |
A numeric vector. |
pct |
percent of area to drop |
Value
a numeric vector indicating the indices of the elements to keep.
Author(s)
Aniko B. Toth anikobtoth@gmail.com
References
IUCN (2024). Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.). Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
See Also
Other AOO functions:
createGrid(),
getAOO(),
jplot(),
makeAOOGrid()
trend class
Description
A class to represent change in area over time for an ecosystem.
Slots
inputbinary raster or list of sf POLYGON objects representing the input ecosystem extent
areasthe area of the ecosystem in each layer or list element
modela fitted model object typically of the class lm containing the model used to calculate the trend
netdiffdifference between the area in the first layer or list element and the last.
diffraster stack showing change over layers or list elements of the ecosystem extent.
Fit linear model with log-link.
Description
fit_lm_ll produces a simple model to estimate trends in short time series.
Usage
fit_lm_ll(df)
fit_glm_ll(df)
fit_spline(df)
Arguments
df |
a data frame containing the columns "area" and "t" for time. Time can be an index or year. |
Value
an lm object
Author(s)
Aniko B. Toth anikobtoth@gmail.com