| Title: | Tools for the IUCN Red List of Ecosystems and Species |
|---|---|
| Description: | A toolbox created by members of the International Union for Conservation of Nature (IUCN) Red List of Ecosystems Committee for Scientific Standards. Primarily, it is a set of tools suitable for calculating the metrics required for making assessments of species and ecosystems against the IUCN Red List of Threatened Species and the IUCN Red List of Ecosystems categories and criteria. See the IUCN website for detailed guidelines, the criteria, publications and other information. |
| Authors: | Calvin Lee [aut] (Original functions and examples, ORCID: <https://orcid.org/0000-0001-8277-8614>), Nicholas Murray [aut] (Original functions and examples, ORCID: <https://orcid.org/0000-0002-4008-3053>), Aniko Toth [cre, aut] (Updated functions, classes and methods, ORCID: <https://orcid.org/0000-0002-3063-1917>), José R. Ferrer-Paris [aut] (Documentation, contributions to classes and methods, ORCID: <https://orcid.org/0000-0002-9554-3395>) |
| Maintainer: | Aniko Toth <[email protected]> |
| License: | GPL (>=3)| file LICENSE |
| Version: | 2.0.0 |
| Built: | 2026-05-31 06:27:59 UTC |
| Source: | https://github.com/red-list-ecosystem/redlistr |
Area of mangroves in 2000 and 2017
aa
aA data frame with 2 rows and 3 columns:
name of the layer
raster value from which area was computed
area in km2
computed from mangrove.2000 and mangrove.2017 using getArea
Mangrove distribution from the northern regions of Western Port Bay, Victoria, Australia, in the year 2000.
a.2000a.2000
a.2000A data frame with 1 row and 3 columns:
name of the layer
raster value from which area was computed
area in km2
The dataset is stored as a GeoTIFF file in inst/extdata and can be loaded with:
terra::rast(system.file("extdata", "example_distribution_2000.tif", package = "redlistr"))
The dataset is stored as a GeoTIFF file in inst/extdata and can be loaded with:
terra::rast(system.file("extdata", "example_distribution_2017.tif", package = "redlistr"))
Mangrove area
Area of mangroves in 2000
https://onlinelibrary.wiley.com/doi/10.1111/j.1466-8238.2010.00584.x/abstract Mangrove distribution data
Mangrove distribution from the northern regions of Western Port Bay, Victoria, Australia, in the year 2017.
computed from mangrove.2000 using getArea
Area of mangroves in 2017
a.2017a.2017
a.2017A data frame with 1 row and 3 columns:
name of the layer
raster value from which area was computed
area in km2
computed from mangrove.2017 using getArea
A class to represent an AOO grid object
namethe name of the assessment unit
gridan AOO grid as a shapefile
AOOthe number of grid squares in grid
paramsa named vector of input parameters (grid size, jitter, n_jitter)
pctrulelogical indicating whether the 1% rule was applied
inputthe input ecosystem data used to generate the AOO grid
AOOvalsthe list of AOO values
as.list method for AOOgrid object
## S3 method for class 'AOOgrid' as.list(x, ...)## S3 method for class 'AOOgrid' as.list(x, ...)
x |
an AOOgrid object |
... |
additional arguments |
as.list method for EOO object
## S3 method for class 'EOO' as.list(x, ...)## S3 method for class 'EOO' as.list(x, ...)
x |
an EOO object |
... |
additional arguments |
bundle performs AOO and EOO calculations on an input object and returns the results as a table
bundle(input_data, names_from = NA, ...)bundle(input_data, names_from = NA, ...)
input_data |
Spatial object of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
names_from |
name of the column containing ecosystem names. If missing all features will be analysed together. Only needed for vector data. |
... |
Additional graphical parameters passed to getAOO(). |
a data.frame containing AOO and EOO information for all input units as rows.
Aniko B. Toth [email protected]
Other synthesis functions:
list2table()
createGrid produces empty grid which can be used as the basis to help
compute AOO.
createGrid(input_data, cell_size = 10000)createGrid(input_data, cell_size = 10000)
input_data |
Spatial object (sf or SpatRaster) of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
cell_size |
A number specifying the width of the desired grid square (in same units as your coordinate reference system) |
A regular grid raster with extent input_data expanded by two
cells in each direction and grid size cell_size. Each grid square has a
unique raster value that serves as its identification number.
Nicholas Murray [email protected], Calvin Lee [email protected], Aniko B. Toth [email protected]
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
Other AOO functions:
getAOO(),
jplot(),
makeAOOGrid(),
top_pct()
A class to represent an EOO convex hull object
namethe name of the assessment unit
polan EOO convex hull polygon
EOOthe area of the EOO polygon as a numeric
unitthe unit in which the area is provided
inputthe input ecosystem data used to generate the EOO polygon
extrapolateEstimate uses rates of decline from getDeclineStats
to extrapolate estimates to a given time
extrapolateEstimate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)extrapolateEstimate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)
A.t1 |
Area at time t1 |
year.t1 |
Year of time t1 |
nYears |
Number of years since t1 for prediction. Use negative values for backcasting |
ARD |
Absolute rate of decline |
PRD |
Proportional rate of decline |
ARC |
Annual rate of change |
A dataframe with the forecast year, and a combination of:
Values as extrapolated with absolute rate of decline (ARD)
Values as extrapolated with proportional rate of decline (PRD)
Values as extrapolated with annual rate of change (ARC)
Nicholas Murray [email protected], Calvin Lee [email protected]
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp. https://doi.org/10.2305/CJDF9122
Other change_functions:
futureAreaEstimate(),
sequentialExtrapolate()
a.r1 <- 23.55 a.r2 <- 15.79 decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012, methods = 'PRD') a.2040.PRD <- extrapolateEstimate(a.r1, a.r2, year.t1 = 1990, nYears = 50, PRD = decline.stats$PRD)a.r1 <- 23.55 a.r2 <- 15.79 decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012, methods = 'PRD') a.2040.PRD <- extrapolateEstimate(a.r1, a.r2, year.t1 = 1990, nYears = 50, PRD = decline.stats$PRD)
futureAreaEstimate is now deprecated, please use
extrapolateEstimate instead
futureAreaEstimate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)futureAreaEstimate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)
A.t1 |
Area at time t1 |
year.t1 |
Year of time t1 |
nYears |
Number of years since t1 for area prediction |
ARD |
Absolute rate of decline |
PRD |
Proportional rate of decline |
ARC |
Annual rate of change |
A dataframe with the forecast year, and a combination of:
Future area as estimated with absolute rate of decline (ARD)
Future area as estimated with proportional rate of decline (PRD)
Future area as estimated with annual rate of change (ARC)
Nicholas Murray [email protected], Calvin Lee [email protected]
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp. https://doi.org/10.2305/CJDF9122
Other change_functions:
extrapolateEstimate(),
sequentialExtrapolate()
getAOO determines the number of area of occupancy (AOO) grid cells
occupied by a species or ecosystem. It includes capability for specifying
whether at least one percent of the grid cell needs to be occupied before it
is counted in the AOO. This functionality is important for assessing the IUCN
Red List of Ecosystems Criteria B.
getAOO( input_data, cell_size = 10000, names_from = NA, bottom_1pct_rule = TRUE, percent = 1, jitter = TRUE, n_jitter = 35 )getAOO( input_data, cell_size = 10000, names_from = NA, bottom_1pct_rule = TRUE, percent = 1, jitter = TRUE, n_jitter = 35 )
input_data |
Spatial object (sf or SpatRaster) of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
cell_size |
A number specifying the width of the desired grid square (in same units as your coordinate reference system) |
names_from |
the name of the column containing ecosystem labels |
bottom_1pct_rule |
Logical. If |
percent |
Numeric. The minimum percent to be applied as a threshold for
the |
jitter |
logical. Whether grid randomization should be applied to units with low grid counts. |
n_jitter |
the number of grids to test for ecosystems near the AOO thresholds. Ignored if jitter = FALSE. |
an object of class AOOgrid or a list of AOOgrid objects. Ecosystems that received an AOO of 60 cells or fewer on a first pass are run with a jittered grid with n specified by n_jitter
Nicholas Murray [email protected], Calvin Lee [email protected], Aniko B. Toth [email protected]
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
Other AOO functions:
createGrid(),
jplot(),
makeAOOGrid(),
top_pct()
getArea reports the area of ecosystem units provided as spatial data
getArea(x, names_from = NA, ...)getArea(x, names_from = NA, ...)
x |
A SpatRaster, SpatVector, or an sf object with POLYGONS geometry. |
names_from |
a column names containing ecosystem labels, as a string or dplyr-style column name. Only required for SpatVector and sf types. Units are assumed to be delineated by raster value for SpatRasters. |
... |
Addition arguments based on input format |
A data frame containing ecosystem identifiers and the total area of the ecosystem units in x as a units vector (km^2). For raster bricks it also contains the layer number.
Nicholas Murray [email protected], Calvin Lee [email protected], Aniko B. Toth [email protected]
Other Change functions:
getAreaChange(),
getAreaTrend(),
getDeclineStats()
getAreaChange reports the difference in area between two inputs. Inputs
can be SpatRaster, SpatVector, sf or a data frame of areas and may contain
data for multiple ecosystem types. Ensure x and y are the same data type.
If using data frame as input, ensure areas are measured in km2
getAreaChange(x, y, names_from_x = NA, names_from_y = NA)getAreaChange(x, y, names_from_x = NA, names_from_y = NA)
x |
SpatRaster, SpatVector, or sf object representing one or more ecosystems or a data frame with two columns, one of them labeled "area", and the other containing ecosystem labels names_from_x. |
y |
SpatRaster, SpatVector, or sf object representing one or more ecosystems or a data frame with two columns, one of them labeled "area", and the other containing ecosystem labels names_from_y. |
names_from_x |
name of column containing ecosystem labels. Ignored if x is a raster. |
names_from_y |
name of column containing ecosystem labels. Ignored if y is a raster. names_from_x used if not provided. |
Returns a table containing ecosystem labels, areas, and the difference in area of the two inputs in km2
Nicholas Murray [email protected], Calvin Lee [email protected], Aniko B. Toth [email protected]
Other Change functions:
getArea(),
getAreaTrend(),
getDeclineStats()
if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m1 <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), 25, 20) r1 <- terra::rast(m1) terra::crs(r1) <- "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs" m2 <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), 25, 20) r2 <- terra::rast(m2) terra::crs(r2) <- "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs" getAreaChange(r1, r2) }, silent = TRUE) }if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m1 <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), 25, 20) r1 <- terra::rast(m1) terra::crs(r1) <- "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs" m2 <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), 25, 20) r2 <- terra::rast(m2) terra::crs(r2) <- "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs" getAreaChange(r1, r2) }, silent = TRUE) }
getEOOarea wrapper that extracts the area slot of the EOO input
getAreaEOO(EOO)getAreaEOO(EOO)
EOO |
an object of class EOO |
an integer
Other EOO functions:
getEOO(),
makeEOO()
getAreaTrend is used to calculate changes in area over time. Output
is a list can be used to easily visualise trends for one ecosystem at a time.
getAreaTrend(x, names_from = NA)getAreaTrend(x, names_from = NA)
x |
SpatRaster with multiple layers or data frame containing two numerical columns "area" and "time". The data.frame can contain an additional column containing a key, whose name should be placed in names_from. |
names_from |
name of column containing ecosystem labels. Ignored if x is a raster. |
returns a list
Aniko B. Toth [email protected]
Other Change functions:
getArea(),
getAreaChange(),
getDeclineStats()
getDeclineStats calculates the Proportional Rate of Decline (PRD),
Absolute Rate of Decline (ARD) and Annual Rate of Change (ARC), given two
areas at two points in time. Also provides the total area difference. Inputs
are usually the results from getArea.
getDeclineStats(A.t1, A.t2, year.t1, year.t2, methods)getDeclineStats(A.t1, A.t2, year.t1, year.t2, methods)
A.t1 |
Area at time t1 |
A.t2 |
Area at time t2 |
year.t1 |
Year of time t1 |
year.t2 |
Year of time t2 |
methods |
Method(s) used to calculate rate of decline. Either 'PRD', 'ARD', and/or 'ARC'. See vignette to see a more detailed explanation for each of them. |
A dataframe with absolute differences between the two inputs, and a selection of:
Proportional Rate of Decline (PRD)
Absolute Rate of Decline (ARD)
Annual Rate of Change (ARC)
Nicholas Murray [email protected], Calvin Lee [email protected]
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp. https://doi.org/10.2305/CJDF9122 Puyravaud, J.-P. 2003. Standardizing the calculation of the annual rate of deforestation. Forest Ecology and Management, 177, 593-596.
Other Change functions:
getArea(),
getAreaChange(),
getAreaTrend()
a.r1 <- 23.55 a.r2 <- 15.79 decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012, methods = c('ARD', 'ARC'))a.r1 <- 23.55 a.r2 <- 15.79 decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012, methods = c('ARD', 'ARC'))
getEOO calculates the area of the EOO polygon generated from
makeEOO the provided data and returns an EOO class object or a list of these with
defined summary and plot functions available.
getEOO(input_data, names_from = NA)getEOO(input_data, names_from = NA)
input_data |
Spatial object of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
names_from |
name of the column containing ecosystem names. If missing all features will be analysed together. Only needed for vector data. |
An object of type EOO or a list of EOO objects that store the EOO polygon, its area, and its input_data
Nicholas Murray [email protected], Calvin Lee [email protected]
Other EOO functions:
getAreaEOO(),
makeEOO()
if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20) r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs") EOO <- getEOO(r1) }, silent = TRUE) }if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20) r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs") EOO <- getEOO(r1) }, silent = TRUE) }
hist method for AOOgrid objects
## S4 method for signature 'AOOgrid' hist(x, ...)## S4 method for signature 'AOOgrid' hist(x, ...)
x |
an AOOgrid object |
... |
Additional graphical parameters passed to |
jplot creates an elbow plot of the min AOO against
the number of grid replicates run. Jplots that fall to the
minimum value well before the highest n are robust.
jplot(x)jplot(x)
x |
an AOOgrid object |
NULL; plots min AOO against number of reps
Aniko B. Toth [email protected]
Other AOO functions:
createGrid(),
getAOO(),
makeAOOGrid(),
top_pct()
list2table wrapper that summarises a list of EOO or AOOgrid objects as a table.
list2table(l)list2table(l)
l |
a list of EOO or AOOgrid objects |
a data.frame
Other synthesis functions:
bundle()
makeAOOGrid is a generic function that creates grids representing the
area of occupancy for distributions based on the input spatial data. It
includes capability for specifying whether the least occupied cells collectively
containing less than 1% of the ecosystem are counted in the AOO. This functionality is
important for assessing the IUCN Red List of Ecosystems Criteria B.
makeAOOGrid( input_data, cell_size = 10000, names_from = NA, bottom_1pct_rule = TRUE, percent = 1, jitter = TRUE, n_jitter = 35 )makeAOOGrid( input_data, cell_size = 10000, names_from = NA, bottom_1pct_rule = TRUE, percent = 1, jitter = TRUE, n_jitter = 35 )
input_data |
Spatial object (sf or SpatRaster) of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
cell_size |
A number specifying the width of the desired grid square (in same units as your coordinate reference system) |
names_from |
the name of the column containing ecosystem labels |
bottom_1pct_rule |
Logical. If |
percent |
Numeric. The minimum percent to be applied as a threshold for
the |
jitter |
logical. Whether grid randomization should be applied to units with low grid counts. |
n_jitter |
the number of grids to test for ecosystems near the AOO thresholds. Ignored if jitter = FALSE. |
A shapefile of grid cells occupied by an ecosystem or species, or a list of these if multiple ecosystems were input.
Nicholas Murray [email protected], Calvin Lee [email protected], Aniko B. Toth [email protected]
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
Other AOO functions:
createGrid(),
getAOO(),
jplot(),
top_pct()
if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20) r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs") AOO_grid <- makeAOOGrid(r1, cell_size = 3) }, silent = TRUE) }if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20) r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs") AOO_grid <- makeAOOGrid(r1, cell_size = 3) }, silent = TRUE) }
makeEOO is a generic function that creates a minimum convex polygon
enclosing all occurrences of the ecosystems provided in the input data. If the input provided
is a raster layer, the points are taken from a buffer that has the radius of
half of the shorter edge of the pixel around the centroid.
makeEOO(input_data, names_from)makeEOO(input_data, names_from)
input_data |
Spatial object of an ecosystem or species distribution. Please use a CRS with units measured in metres. |
names_from |
name of the column containing ecosystem names. If missing all features will be analysed together. Only needed for vector data. |
An object of class sf representing the EOO of
input_data, or a list of sf objects if multiple ecosystems were input.
Also inherits its CRS from input_data.
Nicholas Murray [email protected], Calvin Lee [email protected]
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp. https://doi.org/10.2305/CJDF9122
Other EOO functions:
getAreaEOO(),
getEOO()
if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20) r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs") EOO.polygon <- makeEOO(r1) }, silent = TRUE) }if (requireNamespace("terra", quietly = TRUE)) { ok <- try({ m <- matrix(sample(1:4, 500, replace = TRUE, prob = c(4,1,1,6)), nrow=25, ncol=20) r1 <- terra::rast(m, crs = "+proj=utm +zone=55 +south +datum=WGS84 +units=m +no_defs") EOO.polygon <- makeEOO(r1) }, silent = TRUE) }
plot method for AOOgrid object
## S4 method for signature 'AOOgrid,ANY' plot(x, title = x@name)## S4 method for signature 'AOOgrid,ANY' plot(x, title = x@name)
x |
an AOOgrid object |
title |
plot title, defaults to the assessment unit name. |
plot method for EOO object
## S4 method for signature 'EOO,ANY' plot(x, title = x@name)## S4 method for signature 'EOO,ANY' plot(x, title = x@name)
x |
an EOO object |
title |
Plot title, defaults to name of assessment unit. |
plot method for trend object
## S4 method for signature 'trend,ANY' plot(x, y, ...)## S4 method for signature 'trend,ANY' plot(x, y, ...)
x |
an trend object |
y |
Ignored. Included for consistency with the |
... |
Additional graphical parameters passed to |
sequentialExtrapolate uses rates of decline from getDeclineStats and
generates a sequence of estimates at regular time-steps. Useful for
generating a sequence for plotting graphs.
sequentialExtrapolate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)sequentialExtrapolate(A.t1, year.t1, nYears, ARD = NA, PRD = NA, ARC = NA)
A.t1 |
Area at time t1 |
year.t1 |
Year of time t1 |
nYears |
Number of years since t1 for prediction. Use negative values for backcasting |
ARD |
Absolute rate of decline |
PRD |
Proportional rate of decline |
ARC |
Annual rate of change |
A dataframe with the forecast year, and a combination of:
Sequence of values as extrapolated with absolute rate of decline (ARD)
Sequence of values as extrapolated with proportional rate of decline (PRD)
Sequence of values as extrapolated with annual rate of change (ARC)
Calvin Lee [email protected]
IUCN 2024. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.) Gland, Switzerland: IUCN. ix + 94pp. https://doi.org/10.2305/CJDF9122
Other change_functions:
extrapolateEstimate(),
futureAreaEstimate()
a.r1 <- 23.55 a.r2 <- 15.79 decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012, methods = 'PRD') a.2040.PRD.seq <- sequentialExtrapolate(a.r1, a.r2, year.t1 = 1990, nYears = 50, PRD = decline.stats$PRD)a.r1 <- 23.55 a.r2 <- 15.79 decline.stats <- getDeclineStats(a.r1, a.r2, year.t1 = 1990, year.t2 = 2012, methods = 'PRD') a.2040.PRD.seq <- sequentialExtrapolate(a.r1, a.r2, year.t1 = 1990, nYears = 50, PRD = decline.stats$PRD)
show method for AOOgrid object
## S4 method for signature 'AOOgrid' show(object)## S4 method for signature 'AOOgrid' show(object)
object |
an AOOgrid object |
show method for EOO object
## S4 method for signature 'EOO' show(object)## S4 method for signature 'EOO' show(object)
object |
an EOO object |
summary method for AOOgrid object
## S4 method for signature 'AOOgrid' summary(object)## S4 method for signature 'AOOgrid' summary(object)
object |
an AOOgrid object |
summary method for EOO object
## S4 method for signature 'EOO' summary(object)## S4 method for signature 'EOO' summary(object)
object |
an EOO object |
summary method for trend object
## S4 method for signature 'trend' summary(object)## S4 method for signature 'trend' summary(object)
object |
a trend object |
top_pct returns the vector positions of the largest elements
collectively comprising a given percentage more of the vector sum. This function
helps perform the bottom_1pct_rule when selecting the AOO grid by
identifying grid positions to keep.
top_pct(v, pct = 99)top_pct(v, pct = 99)
v |
A numeric vector. |
pct |
percent of area to drop |
a numeric vector indicating the indeces of the elements to keep.
Aniko B. Toth [email protected]
IUCN (2024). Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 2.0. Keith, D.A., Ferrer-Paris, J.R., Ghoraba, S.M.M., Henriksen, S., Monyeki, M., Murray, N.J., Nicholson, E., Rowland, J., Skowno, A., Slingsby, J.A., Storeng, A.B., Valderrábano, M. & Zager, I. (Eds.). Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
Other AOO functions:
createGrid(),
getAOO(),
jplot(),
makeAOOGrid()
fit_lm_ll produces a simple model to estimate trends in short time series.
fit_lm_ll(df) fit_glm_ll(df) fit_spline(df)fit_lm_ll(df) fit_glm_ll(df) fit_spline(df)
df |
a data frame containing the columns "area" and "t" for time. Time can be an index or year. |
an lm object
Aniko B. Toth [email protected]
A class to represent change in area over time for an ecosystem.
inputbinary raster or list of sf POLYGON objects representing the input ecosystem extent
areasthe area of the ecosystem in each layer or list element
modela fitted model object typically of the class lm containing the model used to calculate the trend
netdiffdifference between the area in the first layer or list element and the last.
diffraster stack showing change over layers or list elements of the ecosystem extent.